@@ -1,5 +1,5 @@
 """Augment pandas DataFrame with methods for machine learning"""
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 import logging
 from typing import Union, List, Callable, Any
@@ -32,4 +32,4 @@ class Typing(object):
     Series = pd.Series
     Pandas = Union[DataFrame, Series]
     PdIndex = pd.Index
-    MlGetItem = Union[str, List['MlGetItem'], Callable[[Any], Union[pd.DataFrame, pd.Series]], Constant]
\ No newline at end of file
+    _Selector = Union[str, List['MlGetItem'], Callable[[Any], Union[pd.DataFrame, pd.Series]], Constant]
\ No newline at end of file
